/**
 * External dependencies
 */
import React, { useState, useEffect } from 'react';
export default function createExPlatClientReactHelpers(exPlatClient) {
    var useExperiment = function (experimentName) {
        var previousExperimentName = useState(experimentName)[0];
        var _a = useState([
            true,
            null,
        ]), state = _a[0], setState = _a[1];
        useEffect(function () {
            var isSubscribed = true;
            exPlatClient.loadExperimentAssignment(experimentName).then(function (experimentAssignment) {
                if (isSubscribed) {
                    setState([false, experimentAssignment]);
                }
            });
            return function () {
                isSubscribed = false;
            };
            // We don't expect experimentName to ever change and if it does we want to assignment to stay constant.
            // eslint-disable-next-line react-hooks/exhaustive-deps
        }, []);
        if (experimentName !== previousExperimentName &&
            !previousExperimentName.startsWith('explat_test')) {
            exPlatClient.config.logError({
                message: '[ExPlat] useExperiment: experimentName should never change between renders!',
            });
        }
        return state;
    };
    var Experiment = function (_a) {
        var defaultExperience = _a.defaultExperience, treatmentExperience = _a.treatmentExperience, loadingExperience = _a.loadingExperience, experimentName = _a.name;
        var _b = useExperiment(experimentName), isLoading = _b[0], experimentAssignment = _b[1];
        if (isLoading) {
            return React.createElement(React.Fragment, null, loadingExperience);
        }
        else if (!(experimentAssignment === null || experimentAssignment === void 0 ? void 0 : experimentAssignment.variationName)) {
            return React.createElement(React.Fragment, null, defaultExperience);
        }
        return React.createElement(React.Fragment, null, treatmentExperience);
    };
    var ProvideExperimentData = function (_a) {
        var children = _a.children, experimentName = _a.name;
        var _b = useExperiment(experimentName), isLoading = _b[0], experimentAssignment = _b[1];
        return children(isLoading, experimentAssignment);
    };
    return {
        useExperiment: useExperiment,
        Experiment: Experiment,
        ProvideExperimentData: ProvideExperimentData,
    };
}
